@@ -180,7 +180,10 @@ class Property(ModelSQL, ModelView):
 
     def _set_values(self, name, model, res_id, val, field_id):
         user_obj = self.pool.get('res.user')
-        user = user_obj.browse(Transaction().user)
+        user_id = Transaction().user
+        if user_id == 0:
+            user_id = Transaction().context.get('user', user_id)
+        user = user_obj.browse(user_id)
         res = super(Property, self)._set_values(name, model, res_id, val, 
                 field_id)
         if user:
@@ -188,7 +191,7 @@ class Property(ModelSQL, ModelView):
         return res
 
     def search(self, domain, offset=0, limit=None, order=None, count=False):
-        if Transaction().user == 0:
+        if Transaction().user == 0 and not 'user' in Transaction().context:
             domain = ['AND', domain[:], ('company', '=', False)]
         return super(Property, self).search(domain, offset=offset,
                 limit=limit, order=order, count=count)
